<?php

namespace Urdtlv\Clientpays\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Urdtlv\Clientpays\Http\Requests\ClientPayRequest;
use Urdtlv\Clientpays\Interfaces\ClientPayRepositoryInterface;
use Urdtlv\Clientpays\Models\ClientPay;

/**
 * Resource controller class for client_pay.
 */
class ClientPayResourceController extends BaseController
{

    /**
     * Initialize client_pay resource controller.
     *
     * @param type ClientPayRepositoryInterface $client_pay
     *
     * @return null
     */
    public function __construct(ClientPayRepositoryInterface $client_pay)
    {
        parent::__construct();
        $this->repository = $client_pay;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Urdtlv\Clientpays\Repositories\Criteria\ClientPayResourceCriteria::class);
    }

    /**
     * Display a list of client_pay.
     *
     * @return Response
     */
    public function index(ClientPayRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Urdtlv\Clientpays\Repositories\Presenter\ClientPayPresenter::class)
                ->$function();
        }

        $client_pays = $this->repository->paginate();

        return $this->response->title(trans('clientpays::client_pay.names'))
            ->view('clientpays::client_pay.index', true)
            ->data(compact('client_pays'))
            ->output();
    }

    /**
     * Display client_pay.
     *
     * @param Request $request
     * @param Model   $client_pay
     *
     * @return Response
     */
    public function show(ClientPayRequest $request, ClientPay $client_pay)
    {

        if ($client_pay->exists) {
            $view = 'clientpays::client_pay.show';
        } else {
            $view = 'clientpays::client_pay.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('clientpays::client_pay.name'))
            ->data(compact('client_pay'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new client_pay.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ClientPayRequest $request)
    {

        $client_pay = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('clientpays::client_pay.name')) 
            ->view('clientpays::client_pay.create', true) 
            ->data(compact('client_pay'))
            ->output();
    }

    /**
     * Create new client_pay.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ClientPayRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $client_pay                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('clientpays::client_pay.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('clientpays/client_pay/' . $client_pay->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/clientpays/client_pay'))
                ->redirect();
        }

    }

    /**
     * Show client_pay for editing.
     *
     * @param Request $request
     * @param Model   $client_pay
     *
     * @return Response
     */
    public function edit(ClientPayRequest $request, ClientPay $client_pay)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('clientpays::client_pay.name'))
            ->view('clientpays::client_pay.edit', true)
            ->data(compact('client_pay'))
            ->output();
    }

    /**
     * Update the client_pay.
     *
     * @param Request $request
     * @param Model   $client_pay
     *
     * @return Response
     */
    public function update(ClientPayRequest $request, ClientPay $client_pay)
    {
        try {
            $attributes = $request->all();

            $client_pay->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('clientpays::client_pay.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('clientpays/client_pay/' . $client_pay->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('clientpays/client_pay/' . $client_pay->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the client_pay.
     *
     * @param Model   $client_pay
     *
     * @return Response
     */
    public function destroy(ClientPayRequest $request, ClientPay $client_pay)
    {
        try {

            $client_pay->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('clientpays::client_pay.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('clientpays/client_pay/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('clientpays/client_pay/' . $client_pay->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple client_pay.
     *
     * @param Model   $client_pay
     *
     * @return Response
     */
    public function delete(ClientPayRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('clientpays::client_pay.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('clientpays/client_pay'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/clientpays/client_pay'))
                ->redirect();
        }

    }

    /**
     * Restore deleted client_pays.
     *
     * @param Model   $client_pay
     *
     * @return Response
     */
    public function restore(ClientPayRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('clientpays::client_pay.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/clientpays/client_pay'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/clientpays/client_pay/'))
                ->redirect();
        }

    }

}
