<?php

namespace Urdtlv\Clientpays\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Urdtlv\Clientpays\Http\Requests\ClientPayRequest;
use Urdtlv\Clientpays\Models\ClientPay;

/**
 * Admin web controller class.
 */
class ClientPayWorkflowController extends BaseController
{

    /**
     * Workflow controller function for client_pay.
     *
     * @param Model   $client_pay
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ClientPayRequest $request, ClientPay $client_pay, $step)
    {

        try {

            $client_pay->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('clientpays::client_pay.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/client_pay/client_pay/' . $client_pay->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/client_pay/client_pay/' . $client_pay->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for client_pay.
     *
     * @param Model   $client_pay
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(ClientPay $client_pay, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $client_pay->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('clientpays::client_pay.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('clientpays::admin.client_pay.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('clientpays::admin.client_pay.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('clientpays::admin.client_pay.message', $data)->render();

        }

    }
}
