<?php

namespace Urdtlv\Clientpays\Policies;

use Litepie\User\Contracts\UserPolicy;
use Urdtlv\Clientpays\Models\ClientPay;

class ClientPayPolicy
{

    /**
     * Determine if the given user can view the client_pay.
     *
     * @param UserPolicy $user
     * @param ClientPay $client_pay
     *
     * @return bool
     */
    public function view(UserPolicy $user, ClientPay $client_pay)
    {
        if ($user->canDo('clientpays.client_pay.view') && $user->isAdmin()) {
            return true;
        }

        return $client_pay->user_id == user_id() && $client_pay->user_type == user_type();
    }

    /**
     * Determine if the given user can create a client_pay.
     *
     * @param UserPolicy $user
     * @param ClientPay $client_pay
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('clientpays.client_pay.create');
    }

    /**
     * Determine if the given user can update the given client_pay.
     *
     * @param UserPolicy $user
     * @param ClientPay $client_pay
     *
     * @return bool
     */
    public function update(UserPolicy $user, ClientPay $client_pay)
    {
        if ($user->canDo('clientpays.client_pay.edit') && $user->isAdmin()) {
            return true;
        }

        return $client_pay->user_id == user_id() && $client_pay->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given client_pay.
     *
     * @param UserPolicy $user
     * @param ClientPay $client_pay
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ClientPay $client_pay)
    {
        return $client_pay->user_id == user_id() && $client_pay->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given client_pay.
     *
     * @param UserPolicy $user
     * @param ClientPay $client_pay
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ClientPay $client_pay)
    {
        if ($user->canDo('clientpays.client_pay.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given client_pay.
     *
     * @param UserPolicy $user
     * @param ClientPay $client_pay
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ClientPay $client_pay)
    {
        if ($user->canDo('clientpays.client_pay.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
