<?php

namespace Urdtlv\Clientpays\Providers;

use Illuminate\Support\ServiceProvider;

class ClientpaysServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'clientpays');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'clientpays');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('urdtlv.clientpays', function ($app) {
            return $this->app->make('Urdtlv\Clientpays\Clientpays');
        });

        // Bind ClientPay to repository
        $this->app->bind(
            'Urdtlv\Clientpays\Interfaces\ClientPayRepositoryInterface',
            \Urdtlv\Clientpays\Repositories\Eloquent\ClientPayRepository::class
        );
        // Bind ClientOrder to repository
        $this->app->bind(
            'Urdtlv\Clientpays\Interfaces\ClientOrderRepositoryInterface',
            \Urdtlv\Clientpays\Repositories\Eloquent\ClientOrderRepository::class
        );

        $this->app->register(\Urdtlv\Clientpays\Providers\AuthServiceProvider::class);
                $this->app->register(\Urdtlv\Clientpays\Providers\EventServiceProvider::class);
        
        $this->app->register(\Urdtlv\Clientpays\Providers\RouteServiceProvider::class);
                $this->app->register(\Urdtlv\Clientpays\Providers\WorkflowServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['urdtlv.clientpays'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('urdtlv/clientpays.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/clientpays')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/clientpays')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
