<?php

namespace Urdtlv\Clientpays\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Urdtlv\Clientpays\Models\ClientOrder;

class ClientOrderAction
{
    /**
     * Perform the complete action.
     *
     * @param ClientOrder $client_order
     *
     * @return ClientOrder
     */
    public function complete(ClientOrder $client_order)
    {
        try {
            $client_order->status = 'complete';
            return $client_order->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param ClientOrder $client_order
     *
     * @return ClientOrder
     */public function verify(ClientOrder $client_order)
    {
        try {
            $client_order->status = 'verify';
            return $client_order->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param ClientOrder $client_order
     *
     * @return ClientOrder
     */public function approve(ClientOrder $client_order)
    {
        try {
            $client_order->status = 'approve';
            return $client_order->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param ClientOrder $client_order
     *
     * @return ClientOrder
     */public function publish(ClientOrder $client_order)
    {
        try {
            $client_order->status = 'publish';
            return $client_order->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param ClientOrder $client_order
     *
     * @return ClientOrder
     */
    public function archive(ClientOrder $client_order)
    {
        try {
            $client_order->status = 'archive';
            return $client_order->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param ClientOrder $client_order
     *
     * @return ClientOrder
     */
    public function unpublish(ClientOrder $client_order)
    {
        try {
            $client_order->status = 'unpublish';
            return $client_order->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
