<?php

namespace Urdtlv\Clientpays\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Urdtlv\Clientpays\Models\ClientPay;

class ClientPayAction
{
    /**
     * Perform the complete action.
     *
     * @param ClientPay $client_pay
     *
     * @return ClientPay
     */
    public function complete(ClientPay $client_pay)
    {
        try {
            $client_pay->status = 'complete';
            return $client_pay->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param ClientPay $client_pay
     *
     * @return ClientPay
     */public function verify(ClientPay $client_pay)
    {
        try {
            $client_pay->status = 'verify';
            return $client_pay->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param ClientPay $client_pay
     *
     * @return ClientPay
     */public function approve(ClientPay $client_pay)
    {
        try {
            $client_pay->status = 'approve';
            return $client_pay->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param ClientPay $client_pay
     *
     * @return ClientPay
     */public function publish(ClientPay $client_pay)
    {
        try {
            $client_pay->status = 'publish';
            return $client_pay->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param ClientPay $client_pay
     *
     * @return ClientPay
     */
    public function archive(ClientPay $client_pay)
    {
        try {
            $client_pay->status = 'archive';
            return $client_pay->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param ClientPay $client_pay
     *
     * @return ClientPay
     */
    public function unpublish(ClientPay $client_pay)
    {
        try {
            $client_pay->status = 'unpublish';
            return $client_pay->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
