<?php

namespace Urdtlv\Clientpays\Workflow;

use Urdtlv\Clientpays\Models\ClientPay;
use Validator;

class ClientPayValidator
{

    /**
     * Determine if the given client_pay is valid for complete status.
     *
     * @param ClientPay $client_pay
     *
     * @return bool / Validator
     */
    public function complete(ClientPay $client_pay)
    {
        return Validator::make($client_pay->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given client_pay is valid for verify status.
     *
     * @param ClientPay $client_pay
     *
     * @return bool / Validator
     */
    public function verify(ClientPay $client_pay)
    {
        return Validator::make($client_pay->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given client_pay is valid for approve status.
     *
     * @param ClientPay $client_pay
     *
     * @return bool / Validator
     */
    public function approve(ClientPay $client_pay)
    {
        return Validator::make($client_pay->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given client_pay is valid for publish status.
     *
     * @param ClientPay $client_pay
     *
     * @return bool / Validator
     */
    public function publish(ClientPay $client_pay)
    {
        return Validator::make($client_pay->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given client_pay is valid for archive status.
     *
     * @param ClientPay $client_pay
     *
     * @return bool / Validator
     */
    public function archive(ClientPay $client_pay)
    {
        return Validator::make($client_pay->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given client_pay is valid for unpublish status.
     *
     * @param ClientPay $client_pay
     *
     * @return bool / Validator
     */
    public function unpublish(ClientPay $client_pay)
    {
        return Validator::make($client_pay->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
